==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/CognitoIdp/AdminAddUserToGroup.pm <==

package Paws::CognitoIdp::AdminAddUserToGroup;
  use Moose;
  has GroupName => (is => 'ro', isa => 'Str', required => 1);
  has Username => (is => 'ro', isa => 'Str', required => 1);
  has UserPoolId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'AdminAddUserToGroup');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoIdp::AdminAddUserToGroup - Arguments for method AdminAddUserToGroup on Paws::CognitoIdp

=head1 DESCRIPTION

This class represents the parameters used for calling the method AdminAddUserToGroup on the 
Amazon Cognito Identity Provider service. Use the attributes of this class
as arguments to method AdminAddUserToGroup.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to AdminAddUserToGroup.

As an example:

  $service_obj->AdminAddUserToGroup(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> GroupName => Str

The group name.



=head2 B<REQUIRED> Username => Str

The username for the user.



=head2 B<REQUIRED> UserPoolId => Str

The user pool ID for the user pool.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method AdminAddUserToGroup in L<Paws::CognitoIdp>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/CognitoIdp/AdminAddUserToGroup.pm <==

package Paws::CognitoIdp::AdminAddUserToGroup;
  use Moose;
  has GroupName => (is => 'ro', isa => 'Str', required => 1);
  has Username => (is => 'ro', isa => 'Str', required => 1);
  has UserPoolId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'AdminAddUserToGroup');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoIdp::AdminAddUserToGroup - Arguments for method AdminAddUserToGroup on L<Paws::CognitoIdp>

=head1 DESCRIPTION

This class represents the parameters used for calling the method AdminAddUserToGroup on the
L<Amazon Cognito Identity Provider|Paws::CognitoIdp> service. Use the attributes of this class
as arguments to method AdminAddUserToGroup.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to AdminAddUserToGroup.

=head1 SYNOPSIS

    my $cognito-idp = Paws->service('CognitoIdp');
    $cognito -idp->AdminAddUserToGroup(
      GroupName  => 'MyGroupNameType',
      UserPoolId => 'MyUserPoolIdType',
      Username   => 'MyUsernameType',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/cognito-idp/AdminAddUserToGroup>

=head1 ATTRIBUTES


=head2 B<REQUIRED> GroupName => Str

The group name.



=head2 B<REQUIRED> Username => Str

The username for the user.



=head2 B<REQUIRED> UserPoolId => Str

The user pool ID for the user pool.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method AdminAddUserToGroup in L<Paws::CognitoIdp>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
